@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2007 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -15,6 +15,14 @@ import parse_datetime
 import glob
 import locale
 
+try:
+    sorted( [] )
+except NameError:
+    def sorted( list_in ):
+        list_out = list( list_in )
+        list_out.sort()
+        return list_out
+
 class CommandError( Exception ):
     def __init__( self, reason ):
         Exception.__init__( self )
@@ -137,7 +145,7 @@ class SvnCommand:
 
     def debug( self, msg, args=() ):
         if self.debug_enabled:
-            print 'Debug:', msg % args
+            print( 'Debug: %s' % (msg % args) )
 
     def initClient( self, config_dir ):
         self.client = pysvn.Client( config_dir )
@@ -152,18 +160,18 @@ class SvnCommand:
         self.client.callback_ssl_server_trust_prompt = self.callback_ssl_server_trust_prompt
 
     def callback_ssl_client_cert_password_prompt( self ):
-        print 'callback_ssl_client_cert_password_prompt'
+        print( 'callback_ssl_client_cert_password_prompt' )
 
     def callback_ssl_client_cert_prompt( self ):
-        print 'callback_ssl_client_cert_prompt'
+        print( 'callback_ssl_client_cert_prompt' )
 
     def callback_ssl_server_prompt( self ):
-        print 'callback_ssl_server_prompt'
+        print( 'callback_ssl_server_prompt' )
 
     def callback_ssl_server_trust_prompt( self, trust_data ):
         for key,value in trust_data.items():
-            print '%s: %s' % (key, value)
-        print
+            print( '%s: %s' % (key, value) )
+        print('')
         answer = ''
         while answer.lower() not in ['p','t','r']:
             sys.stdout.write( '(P)ermanent accept, (T)emporary accept or (R)eject: ' )
@@ -185,13 +193,13 @@ class SvnCommand:
             if self.pysvn_testing != '99.99.99':
                 self.notify_message_list.append( msg )
             else:
-                print msg
+                print( msg )
 
     def callback_getLogin( self, realm, username, may_save ):
-        print 'May save:',may_save
-        print 'Realm:',realm
+        print( 'May save: %s ' % may_save )
+        print( 'Realm: %s ' % realm )
         if username:
-            print 'Username:',username
+            print( 'Username: %s' % username )
         else:
             sys.stdout.write( 'Username: ' )
             username = sys.stdin.readline().strip()
@@ -231,14 +239,14 @@ class SvnCommand:
 
             self.printNotifyMessages()
 
-        except pysvn.ClientError, e:
+        except pysvn.ClientError as e:
             self.printNotifyMessages()
-            print e.args[0]
+            print( e.args[0] )
             return 1
 
-        except CommandError, e:
+        except CommandError as e:
             self.printNotifyMessages()
-            print e.reason()
+            print( e.reason() )
             return 1
 
         return 0
@@ -249,24 +257,24 @@ class SvnCommand:
             # test data for multiple versions of SVN
             self.notify_message_list.sort()
             for msg in self.notify_message_list:
-                print msg
+                print( msg )
             self.notify_message_list = []
 
     def cmd_version( self, args ):
-        print 'PYSVN Version:',pysvn.version
-        print 'SVN Version:',pysvn.svn_version
+        print( 'PYSVN Version: %s' % pysvn.version )
+        print( 'SVN Version: %s' % pysvn.svn_version )
         if hasattr( pysvn, 'svn_api_version' ):
-            print 'SVN API Version:',pysvn.svn_api_version
-        print 'pysvn._pysvn',pysvn._pysvn
+            print( 'SVN API Version: %s' % pysvn.svn_api_version )
+        print( 'pysvn._pysvn %s' % pysvn._pysvn )
 
 
     def cmd_is_url( self, args ):
         path = args.getPositionalArgs( 1 )[0]
         is_url = self.client.is_url( path )
         if is_url:
-            print 'url',path
+            print( 'url %s' % path )
         else:
-            print 'path',path
+            print( 'path %s' % path )
 
     def cmd_add( self, args ):
         recurse = args.getBooleanOption( '--non-recursive', False )
@@ -276,7 +284,7 @@ class SvnCommand:
 
     def cmd_add_to_changelist( self, args ):
         if not hasattr( self.client, add_to_changelist ):
-            print 'Error: add_to_changelist is not supported by this version of Subversion'
+            print( 'Error: add_to_changelist is not supported by this version of Subversion' )
             return
 
         path, changelist = args.getPositionalArgs( 2, 2 )
@@ -291,18 +299,18 @@ class SvnCommand:
         self.printNotifyMessages()
 
         for line in all_lines:
-            print ('%d| r%d | %s | %s | %s' %
+            print( '%d| r%d | %s | %s | %s' %
                 (line['number']
                 ,line['revision'].number
                 ,line['author']
                 ,line['date']
-                ,line['line']))
+                ,line['line']) )
     cmd_ann = cmd_annotate
 
     def cmd_cat( self, args ):
         revision = args.getOptionalRevision( '--revision', 'head' )
         text = self.client.cat( args.getPositionalArgs( 1, 1 )[0], revision=revision )
-        print text
+        print( text )
 
     def cmd_checkout( self, args ):
         recurse = args.getBooleanOption( '--non-recursive', False )
@@ -315,9 +323,9 @@ class SvnCommand:
         self.printNotifyMessages()
 
         if self.revision_update_complete is not None:
-            print 'Checked out revision',self.revision_update_complete.number
+            print( 'Checked out revision %s' % self.revision_update_complete.number )
         else:
-            print 'Checked out unknown revision - checkout failed?'
+            print( 'Checked out unknown revision - checkout failed?' )
 
     cmd_co = cmd_checkout
 
@@ -342,11 +350,11 @@ class SvnCommand:
         self.printNotifyMessages()
 
         if rev is None:
-            print 'Nothing to commit'
+            print( 'Nothing to commit' )
         elif rev.number > 0:
-            print 'Revision',rev.number
+            print( 'Revision %s' % rev.number )
         else:
-            print 'Commit failed'
+            print( 'Commit failed' )
 
     cmd_commit = cmd_checkin
     cmd_ci = cmd_checkin
@@ -363,18 +371,18 @@ class SvnCommand:
         if len(positional_args) == 0:
             positional_args.append( '.' )
 
-        if os.environ.has_key('TEMP'):
+        if 'TEMP' in os.environ:
             tmpdir = os.environ['TEMP']
-        elif os.environ.has_key('TMPDIR'):
+        elif 'TMPDIR' in os.environ:
             tmpdir = os.environ['TMPDIR']
-        elif os.environ.has_key('TMP'):
+        elif 'TMP' in os.environ:
             tmpdir = os.environ['TMP']
         elif os.path.exists( '/usr/tmp' ):
             tmpdir = '/usr/tmp'
         elif os.path.exists( '/tmp' ):
             tmpdir = '/tmp'
         else:
-            print 'No tmp dir!'
+            print( 'No tmp dir!' )
             return
 
         tmpdir = os.path.join( tmpdir, 'svn_tmp' )
@@ -382,7 +390,7 @@ class SvnCommand:
         diff_text = self.client.diff( tmpdir, positional_args[0], recurse=recurse,
                                             revision1=revision1, revision2=revision2,
                                             diff_options=['-u'] )
-        print diff_text.encode('utf-8')
+        print( diff_text )
 
     def cmd_export( self, args ):
         force = args.getBooleanOption( '--force', False )
@@ -406,51 +414,51 @@ class SvnCommand:
 
         entry = self.client.info( path )
 
-        print 'Path:',path
+        print( 'Path: %s' % path )
         if entry.name and entry.name != 'svn:this_dir':
-            print 'Name:',entry.name.encode('utf-8')
+            print( 'Name: %s' % entry.name )
         if entry.url:
-            print 'Url:',entry.url.encode('utf-8')
+            print( 'Url: %s' % entry.url )
         if entry.repos and self.pysvn_testing >= '01.03.00':
-            print 'Repository:',entry.repos
+            print( 'Repository: %s' % entry.repos )
         if entry.uuid:
-            print 'Repository UUID:',entry.uuid
+            print( 'Repository UUID: %s' % entry.uuid )
         if entry.revision.kind == pysvn.opt_revision_kind.number:
-            print 'Revision:',entry.revision.number
+            print( 'Revision: %s' % entry.revision.number )
         if entry.kind == pysvn.node_kind.file:
-            print 'Node kind: file'
+            print( 'Node kind: file' )
         elif entry.kind == pysvn.node_kind.dir:
-            print 'Node kind: directory'
+            print( 'Node kind: directory' )
         elif entry.kind == pysvn.node_kind.none:
-            print 'Node kind: none'
+            print( 'Node kind: none' )
         else:
-            print 'Node kind: unknown'
+            print( 'Node kind: unknown' )
 
         if entry.schedule == pysvn.wc_schedule.normal:
-            print "Schedule: normal"
+            print( "Schedule: normal" )
         elif entry.schedule == pysvn.wc_schedule.add:
-            print "Schedule: add"
+            print( "Schedule: add" )
         elif entry.schedule == pysvn.wc_schedule.delete:
-            print "Schedule: delete"
+            print( "Schedule: delete" )
         elif entry.schedule == pysvn.wc_schedule.replace:
-            print "Schedule: replace"
+            print( "Schedule: replace" )
         if entry.is_copied:
             if entry.copyfrom_url:
-                print 'Copied From URL:', entry.copyfrom_url.encode('utf-8')
+                print( 'Copied From URL: %s' %  entry.copyfrom_url )
             if entry.copyfrom_rev.number:
-                print 'Copied From Rev:', entry.copyfrom_rev.number
+                print( 'Copied From Rev: %s' %  entry.copyfrom_rev.number )
         if entry.commit_author:
-            print 'Last Changed Author:', entry.commit_author.encode('utf-8')
+            print( 'Last Changed Author: %s' %  entry.commit_author )
         if entry.commit_revision.number:
-            print 'Last Changed Rev:', entry.commit_revision.number
+            print( 'Last Changed Rev: %s' %  entry.commit_revision.number )
         if entry.commit_time:
-            print 'Last Changed Date:', fmtDateTime( entry.commit_time )
+            print( 'Last Changed Date: %s' %  fmtDateTime( entry.commit_time ) )
         if entry.text_time:
-            print 'Text Last Updated:', fmtDateTime( entry.text_time )
+            print( 'Text Last Updated: %s' %  fmtDateTime( entry.text_time ) )
         if entry.properties_time and self.pysvn_testing == '99.99.99':
-            print 'Properties Last Updated:', fmtDateTime( entry.properties_time )
+            print( 'Properties Last Updated: %s' %  fmtDateTime( entry.properties_time ) )
         if entry.checksum:
-            print 'Checksum:', entry.checksum
+            print( 'Checksum: %s' %  entry.checksum )
 
     def cmd_info2( self, args ):
         recurse = args.getBooleanOption( '--recursive', True )
@@ -471,59 +479,59 @@ class SvnCommand:
         all_entries = self.client.info2( path, revision=revision,  recurse=recurse )
 
         for path, info in all_entries:
-            print
-            print 'Path:',path.encode('utf-8')
+            print('')
+            print( 'Path: %s' % path )
 
             if info.URL:
-                print 'Url:',info.URL.encode('utf-8')
+                print( 'Url: %s' % info.URL )
             if info.rev:
-                print 'Revision:',info.rev.number
+                print( 'Revision: %s' % info.rev.number )
             if info.repos_root_URL and self.pysvn_testing >= '01.03.00':
-                print 'Repository root URL:',info.repos_root_URL
+                print( 'Repository root URL: %s' % info.repos_root_URL )
             if info.repos_UUID:
-                print 'Repository UUID:',info.repos_UUID
+                print( 'Repository UUID: %s' % info.repos_UUID )
             if info.last_changed_author:
-                print 'Last changed author:',info.last_changed_author.encode('utf-8')
+                print( 'Last changed author: %s' % info.last_changed_author )
             if info.last_changed_date:
-                print 'Last Changed Date:', fmtDateTime( info.last_changed_date )
+                print( 'Last Changed Date: %s' %  fmtDateTime( info.last_changed_date ) )
             if info.last_changed_rev.kind == pysvn.opt_revision_kind.number:
-                print 'Last changed revision:',info.last_changed_rev.number
+                print( 'Last changed revision: %s' % info.last_changed_rev.number )
             if info.kind == pysvn.node_kind.file:
-                print 'Node kind: file'
+                print( 'Node kind: file' )
             elif info.kind == pysvn.node_kind.dir:
-                print 'Node kind: directory'
+                print( 'Node kind: directory' )
             elif info.kind == pysvn.node_kind.none:
-                print 'Node kind: none'
+                print( 'Node kind: none' )
             else:
-                print 'Node kind: unknown'
+                print( 'Node kind: unknown' )
             if info.lock:
-                print 'Lock Owner:',info.lock.owner.encode('utf-8')
-                print 'Lock Creation Date:',fmtDateTime( info.lock.creation_date )
+                print( 'Lock Owner: %s' % info.lock.owner )
+                print( 'Lock Creation Date: %s' % fmtDateTime( info.lock.creation_date ) )
                 if info.lock.expiration_date is not None:
-                    print 'Lock Expiration Date:',fmtDateTime( info.lock.expiration_date )
-                print 'Lock Token:',info.lock.token
-                print 'Lock Comment:'
+                    print( 'Lock Expiration Date: %s' % fmtDateTime( info.lock.expiration_date ) )
+                print( 'Lock Token: %s' % info.lock.token )
+                print( 'Lock Comment:' )
                 if info.lock.comment not in ['', None]:
-                    print info.lock.comment
+                    print( info.lock.comment )
             if info.wc_info:
                 wc_info = info.wc_info
                 if wc_info.schedule == pysvn.wc_schedule.normal:
-                    print "Schedule: normal"
+                    print( "Schedule: normal" )
                 elif wc_info.schedule == pysvn.wc_schedule.add:
-                    print "Schedule: add"
+                    print( "Schedule: add" )
                 elif wc_info.schedule == pysvn.wc_schedule.delete:
-                    print "Schedule: delete"
+                    print( "Schedule: delete" )
                 elif wc_info.schedule == pysvn.wc_schedule.replace:
-                    print "Schedule: replace"
+                    print( "Schedule: replace" )
                 if wc_info.copyfrom_url:
-                    print 'Copied From URL:', wc_info.copyfrom_url.encode('utf-8')
-                    print 'Copied From Rev:', wc_info.copyfrom_rev.number
+                    print( 'Copied From URL: %s' %  wc_info.copyfrom_url )
+                    print( 'Copied From Rev: %s' %  wc_info.copyfrom_rev.number )
                 if wc_info.text_time:
-                    print 'Text Last Updated:', fmtDateTime( wc_info.text_time )
+                    print( 'Text Last Updated: %s' %  fmtDateTime( wc_info.text_time ) )
                 if wc_info.prop_time and self.pysvn_testing == '99.99.99':
-                    print 'Properties Last Updated:', fmtDateTime( wc_info.prop_time )
+                    print( 'Properties Last Updated: %s' %  fmtDateTime( wc_info.prop_time ) )
                 if wc_info.checksum:
-                    print 'Checksum:', wc_info.checksum
+                    print( 'Checksum: %s' %  wc_info.checksum )
 
 
     def cmd_import( self, args ):
@@ -548,28 +556,28 @@ class SvnCommand:
                                     discover_changed_paths=verbose )
 
         for log in all_logs:
-            print '-'*60
-            print ('rev %d: %s | %s | %d lines' %
+            print( '-'*60 )
+            print( 'rev %d: %s | %s | %d lines' %
                 (log.revision.number
                 ,log.author
                 ,fmtDateTime( log.date )
-                ,len( log.message.split('\n') )))
+                ,len( log.message.split('\n') )) )
 
             if len( log.changed_paths ) > 0:
-                print 'Changed paths:'
+                print( 'Changed paths:' )
                 for change_info in log.changed_paths:
                     if change_info.copyfrom_path is None:
-                        print '  %s %s' % (change_info.action, change_info.path)
+                        print( '  %s %s' % (change_info.action, change_info.path) )
                     else:
-                        print ('  %s %s (from %s:%d)' %
+                        print( '  %s %s (from %s:%d)' %
                             (change_info.action
                             ,change_info.path
                             ,change_info.copyfrom_path
-                            ,change_info.copyfrom_revision.number))
+                            ,change_info.copyfrom_revision.number) )
 
-            print log.message
+            print( log.message )
 
-        print '-'*60
+        print( '-'*60 )
 
     def cmd_ls( self, args ):
         recurse = args.getBooleanOption( '--recursive', True )
@@ -585,14 +593,14 @@ class SvnCommand:
                 for file in all_files:
                     args = {}
                     args.update( file )
-                    args['name'] = args['name'].encode('utf-8')  
-                    args['last_author'] = args['last_author'].encode('utf-8')  
+                    args['name'] = args['name']  
+                    args['last_author'] = args['last_author']  
                     args['time_str'] = fmtDateTime( file.time )
                     args['created_rev_num'] = file.created_rev.number
-                    print '%(created_rev_num)7d %(last_author)-10s %(size)6d %(time_str)s %(name)s' % args
+                    print( '%(created_rev_num)7d %(last_author)-10s %(size)6d %(time_str)s %(name)s' % args )
             else:
                 for file in all_files:
-                    print '%(name)s' % file
+                    print( '%(name)s' % file )
 
     def cmd_merge( self, args ):
         recurse = args.getBooleanOption( '--recursive', True )
@@ -635,9 +643,8 @@ class SvnCommand:
         self.client.move( positional_args[0], positional_args[1] )
     cmd_mv = cmd_move
 
-    def props_by_path( self, a, b ):
-        return cmp( a[0], b[0] )
-
+    def key_props_by_path( self, a ):
+        return a[0]
 
     def cmd_proplist( self, args ):
         recurse = args.getBooleanOption( '--recursive', True )
@@ -653,17 +660,16 @@ class SvnCommand:
                 revision = args.getOptionalRevision( '--revision', 'head' )
 
             all_props = self.client.proplist( arg, revision=revision, recurse=recurse )
-            all_props.sort( self.props_by_path )
+            all_props.sort( key=self.key_props_by_path )
 
             for path, props in all_props:
-                print "Properties on '%s':" % path
-                prop_names = props.keys()
-                prop_names.sort()
+                print( "Properties on '%s':" % path )
+                prop_names = sorted( props.keys() )
                 for name in prop_names:
                     if verbose:
-                        print '  %s: %s' % (name, props[name])
+                        print( '  %s: %s' % (name, props[name]) )
                     else:
-                        print '  %s' % name
+                        print( '  %s' % name )
             
     cmd_pl = cmd_proplist
 
@@ -677,10 +683,9 @@ class SvnCommand:
             revision = args.getOptionalRevision( '--revision', 'head' )
 
         props = self.client.propget( positional_args[0], positional_args[1], revision=revision, recurse=recurse )
-        prop_names = props.keys()
-        prop_names.sort()
+        prop_names = sorted( props.keys() )
         for name in prop_names:
-            print '%s: %s' % (name, props[name])
+            print( '%s: %s' % (name, props[name]) )
 
     cmd_pg = cmd_propget
 
@@ -718,11 +723,10 @@ class SvnCommand:
             positional_args.append( '.' )
 
         rev, prop_dict = self.client.revproplist( positional_args[0], revision=revision )
-        print 'Revision:',rev.number
+        print( 'Revision: %s' % rev.number )
         prop_keys = prop_dict.keys()
-        prop_keys.sort()
-        for key in prop_keys:
-            print '%s: %s' % (key, prop_dict[ key ])
+        for key in sorted( prop_keys ):
+            print( '%s: %s' % (key, prop_dict[ key ]) )
 
     cmd_rpl = cmd_revproplist
 
@@ -733,8 +737,8 @@ class SvnCommand:
             positional_args.append( '.' )
 
         rev, value = self.client.revpropget( positional_args[0], positional_args[1], revision=revision )
-        print 'Revision:',rev.number
-        print '%s: %s' % (positional_args[0], value)
+        print( 'Revision: %s' % rev.number )
+        print( '%s: %s' % (positional_args[0], value) )
 
     cmd_rpg = cmd_revpropget
 
@@ -766,7 +770,7 @@ class SvnCommand:
 
     def cmd_remove_from_changelists( self, args ):
         if not hasattr( self.client, remove_from_changelists ):
-            print 'Error: remove_from_changelists is not supported by this version of Subversion'
+            print( 'Error: remove_from_changelists is not supported by this version of Subversion' )
             return
 
         path = args.getPositionalArgs( 1, 1 )[0]
@@ -782,30 +786,34 @@ class SvnCommand:
         positional_args = args.getPositionalArgs( 1, 1 )
         self.client.revert( positional_args[0], recurse=recurse )
 
-    def by_path( self, a, b ):
-        return cmp( a.path, b.path )
+    def key_by_path( self, a ):
+        return a.path
 
     def cmd_status( self, args ):
         recurse = args.getBooleanOption( '--non-recursive', False )
         verbose = args.getBooleanOption( '--verbose', True )
+        quiet = args.getBooleanOption( '--quiet', True )
         ignore = args.getBooleanOption( '--no-ignore', False )
         update = args.getBooleanOption( '--show-updates', True )
 
         positional_args = args.getPositionalArgs( 0 )
         if len(positional_args) == 0:
             all_files = self.client.status( '', recurse=recurse, get_all=verbose, ignore=ignore, update=update )
-            self._cmd_status_print( all_files, verbose, update, ignore )
+            self._cmd_status_print( all_files, verbose, update, ignore, quiet )
         else:
             for arg in positional_args:
                 all_files = self.client.status( arg, recurse=recurse, get_all=verbose, ignore=ignore, update=update )
-                self._cmd_status_print( all_files, verbose, update, ignore )
+                self._cmd_status_print( all_files, verbose, update, ignore, quiet )
 
-    def _cmd_status_print( self, all_files, detailed, update, ignore ):
-        all_files.sort( self.by_path )
+    def _cmd_status_print( self, all_files, detailed, update, ignore, quiet ):
+        all_files.sort( key=self.key_by_path )
         for file in all_files:
             if file.text_status == pysvn.wc_status_kind.ignored and ignore:
                 continue
 
+            if file.text_status == pysvn.wc_status_kind.unversioned and quiet:
+                continue
+
             state = '%s%s%s%s%s' % (wc_status_kind_map[ file.text_status ],
                     wc_status_kind_map[ file.prop_status ],
                     ' L'[ file.is_locked ],
@@ -828,33 +836,37 @@ class SvnCommand:
                 lock_state = 'O'
 
             if file.entry is not None and detailed:
-                print '%s%s %s %6d %6d %-14s %s' % (
-                    state,
+                print( '%s%s %s %6d %6d %-14s %s' %
+                    (state,
                     lock_state,
                     odd_status,
                     file.entry.revision.number,
                     file.entry.commit_revision.number,
-                    file.entry.commit_author.encode('utf-8'),
-                    file.path.encode('utf-8'))
+                    file.entry.commit_author,
+                    file.path) )
 
             elif detailed:
-                print '%s%s %s %6s %6s %-14s %s' % (state, lock_state,
+                print( '%s%s %s %6s %6s %-14s %s' %
+                    (state,
+                    lock_state,
                     odd_status,
                     '',
                     '',
                     '',
-                    file.path.encode('utf-8'))
+                    file.path) )
 
             elif update:
-                print '%s%s %s %s' % (state, lock_state,
+                print( '%s%s %s %s' %
+                    (state,
+                    lock_state,
                     odd_status,
-                    file.path.encode('utf-8'))
+                    file.path) )
 
             else:
                 if( file.text_status != pysvn.wc_status_kind.normal
                 or file.prop_status != pysvn.wc_status_kind.normal
                 or lock_state.strip() != ''):
-                    print '%s%s %s' % (state, lock_state, file.path.encode('utf-8'))
+                    print( '%s%s %s' % (state, lock_state, file.path) )
 
     cmd_st = cmd_status
     cmd_stat = cmd_status
@@ -889,25 +901,27 @@ class SvnCommand:
         rev_list = self.client.update( positional_args[0], recurse=recurse )
         self.printNotifyMessages()
         if type(rev_list) == type([]) and len(rev_list) != 1:
-            print 'rev_list = %r' % [rev.number for rev in rev_list]
+            print( 'rev_list = %r' % [rev.number for rev in rev_list] )
 
         if self.revision_update_complete is not None:
-            print 'Updated to revision',self.revision_update_complete.number
+            print( 'Updated to revision %s' % self.revision_update_complete.number )
         else:
-            print 'Updated to unknown revision - update failed?'
+            print( 'Updated to unknown revision - update failed?' )
 
     cmd_up = cmd_update
 
     def cmd_help( self, args ):
-        print 'Version: pysvn %d.%d.%d-%d' % pysvn.version,'svn %d.%d.%d-%s' % pysvn.svn_version
+        print( 'Version: pysvn %d.%d.%d-%d' % pysvn.version,'svn %d.%d.%d-%s' % pysvn.svn_version )
         valid_cmd_names = [name for name in SvnCommand.__dict__.keys() if name.find('cmd_') == 0]
         valid_cmd_names.sort()
-        print 'Available subcommands:'
+        print( 'Available subcommands:' )
         index = 0
+        line = ''
         for name in valid_cmd_names:
-            print '   %-12s' % name[4:],
+            line = line + ('   %-12s' % name[4:])
             if index % 4 == 3:
-                print
+                print( line )
+                line = ''
             index += 1
 
 # key is long option name, value is 1 if need next arg as value
@@ -1002,7 +1016,7 @@ class SvnArguments:
                 else:
                     self.positional_args.append( arg )
         if need_next_arg:
-            raise CommandError, 'Missing arg to option %s' % name
+            raise CommandError( 'Missing arg to option %s' % name )
 
     def _isOption( self, arg ):
         return arg[0] == '-'
@@ -1010,15 +1024,15 @@ class SvnArguments:
     def _optionInfo( self, opt ):
         # return long_name, arg_needed
         long_opt = short_opt_info.get( opt, opt )
-        if long_opt_info.has_key( long_opt ):
+        if long_opt in long_opt_info:
             return long_opt, long_opt_info[ long_opt ]
-        raise CommandError, 'unknown option %s' % opt
+        raise CommandError( 'unknown option %s' % opt )
 
     def _checkOptionsUsed( self ):
         # check all options have been used
         for opt_name in self.named_options.keys():
-            if not self.used_named_options.has_key( opt_name ):
-                raise CommandError, 'unused option %s' % opt_name
+            if opt_name not in self.used_named_options:
+                raise CommandError( 'unused option %s' % opt_name )
 
     def parsePathWithRevision( self, path_rev, default_rev ):
         if '@' in path_rev:
@@ -1046,14 +1060,14 @@ class SvnArguments:
             try:
                 date = parse_datetime.parse_time( rev_string[1:-2] )
                 return pysvn.Revision( pysvn.opt_revision_kind.date, date )
-            except parse_datetime.DateTimeSyntaxError, e:
-                raise CommandError, e.reason()
+            except parse_datetime.DateTimeSyntaxError as e:
+                raise CommandError( e.reason() )
         # either a rev number or a date
         try:
             return pysvn.Revision( pysvn.opt_revision_kind.number, int(rev_string) )
         except ValueError:
             pass
-        raise CommandError, 'Cannot parse %s as a revision value' % rev_string
+        raise CommandError( 'Cannot parse %s as a revision value' % rev_string )
 
 
     def _splitRevisionString( self, rev_string ):
@@ -1084,24 +1098,24 @@ class SvnArguments:
             return default_command
 
     def haveOption( self, opt_name ):
-        return self.named_options.has_key( opt_name )
+        return opt_name in self.named_options
 
     def getBooleanOption( self, opt_name, present_value=True ):
-        if self.named_options.has_key( opt_name ):
+        if opt_name in self.named_options:
             self.used_named_options[ opt_name ] = None
             return present_value
         else:
             return not present_value
 
     def getOptionalValue( self, opt_name, default ):
-        if self.named_options.has_key( opt_name ):
+        if opt_name in self.named_options:
             self.used_named_options[ opt_name ] = None
             return self.named_options[ opt_name ]
         else:
             return default
 
     def getOptionalRevision( self, opt_name, start_default ):
-        if self.named_options.has_key( opt_name ):
+        if opt_name in self.named_options:
             self.used_named_options[ opt_name ] = None
             rev_string = self.named_options[ opt_name ]
 
@@ -1111,21 +1125,21 @@ class SvnArguments:
 
     def getMandatoryRevisionPair( self, opt_name ):
         # parse a M:N or M as revision pair
-        if not self.named_options.has_key( opt_name ):
-            raise CommandError,'mandatory %s required' % opt_name
+        if opt_name not in self.named_options:
+            raise CommandError( 'mandatory %s required' % opt_name )
 
         self.used_named_options[ opt_name ] = None
 
         rev_strings = self._splitRevisionString( self.named_options[ opt_name ] )
         if len(rev_strings) == 1:
-            raise CommandError,'mandatory %s requires a pair of revisions' % opt_name
+            raise CommandError( 'mandatory %s requires a pair of revisions' % opt_name )
 
         return [self._parseRevisionArg( rev_strings[0] ),
             self._parseRevisionArg( rev_strings[1] )]
 
     def getOptionalRevisionPair( self, opt_name, start_default, end_default=None ):
         # parse a M:N or M as revision pair
-        if self.named_options.has_key( opt_name ):
+        if opt_name in self.named_options:
             self.used_named_options[ opt_name ] = None
             rev_strings = self._splitRevisionString( self.named_options[ opt_name ] )
             if len(rev_strings) == 1:
@@ -1145,9 +1159,9 @@ class SvnArguments:
     def getPositionalArgs( self, min_args, max_args=0 ):
         # check min and max then return the list
         if len(self.positional_args) < min_args:
-            raise CommandError, 'too few arguments - need atlease %d' % min_args
+            raise CommandError( 'too few arguments - need atlease %d' % min_args )
         if max_args != 0 and len(self.positional_args) > max_args:
-            raise CommandError, 'too many arguments - need no more then %d' % max_args
+            raise CommandError( 'too many arguments - need no more then %d' % max_args )
 
         # as this is the last call on the args object we check the option where all used
         self._checkOptionsUsed()
