@@ -20,7 +20,7 @@ pysvn_version_string = '%d.%d.%d-%d' % (pysvn.version[0], pysvn.version[1], pysv
 pysvn_short_version_string = '%d.%d.%d' % (pysvn.version[0], pysvn.version[1], pysvn.version[2])
 svn_version_package_string = '%d%d%d' % (pysvn.svn_version[0], pysvn.svn_version[1], pysvn.svn_version[2])
 svn_version_string = '%d.%d.%d' % (pysvn.svn_version[0], pysvn.svn_version[1], pysvn.svn_version[2])
-
+pysvn_so_string = '_pysvn_%d_%d.so' % (pymaj, pymin)
 pkg_filename = 'py%s%s_pysvn_svn%s-%s-%s' % (pymaj, pymin, svn_version_package_string, pysvn_version_string, processor)
 print 'Info: Packageing %s' % pkg_filename
 build_time  = time.time()
@@ -30,10 +30,16 @@ tmpdir = os.path.join( os.getcwd(), 'tmp' )
 
 if pymaj == 2 and pymin == 3:
     install_dir = '/System/Library/Frameworks/Python.framework/Versions/2.3/lib/python2.3/site-packages'
+
 elif pymaj == 2 and pymin == 4:
     install_dir = '/Library/Frameworks/Python.framework/Versions/2.4/lib/python2.4/site-packages'
+
 elif pymaj == 2 and pymin == 5:
     install_dir = '/Library/Frameworks/Python.framework/Versions/2.5/lib/python2.5/site-packages'
+
+elif pymaj == 2 and pymin == 6:
+    install_dir = '/Library/Frameworks/Python.framework/Versions/2.6/lib/python2.6/site-packages'
+
 else:
     raise RuntimeError( 'Unsupported version of python' )
 
@@ -58,23 +64,34 @@ for kit_dir in [
 
 
 print 'Info: Finding dylibs used by pysvn'
-dylib_list = []
-os.system( 'otool -L ../../Source/pysvn/_pysvn.so >/tmp/pysvn_otool.tmp' )
-for line in file( '/tmp/pysvn_otool.tmp' ).readlines():
-    line = line.strip()
-    if( line.startswith( '/' )
-    and not line.startswith( '/usr/lib' )
-    and not line.startswith( '/System' ) ):
+
+def findDylibs( image, dylib_list, depth=0 ):
+    cmd = 'otool -L "%s" >/tmp/pysvn_otool.tmp' % image
+    #print 'Debug: cmd %r' % cmd
+    os.system( cmd )
+    # always skip the first line that lists the image being dumped
+    for line in file( '/tmp/pysvn_otool.tmp' ).readlines()[1:]:
+        line = line.strip()
         libpath = line.split()[0]
-        print 'Info: Need lib',libpath
-        dylib_list.append( libpath )
+        #print 'Debug: line %r' % line
+        if( libpath.startswith( '/' )               # lines with libs on them
+        and not libpath.startswith( '/usr/lib' )    # ignore libs shipped by Apple
+        and not libpath.startswith( '/System' )     # ignore libs shipped by Apple
+        and not libpath.endswith( '/Python' ) ):    # do not need to ignore python
+            if libpath not in dylib_list:
+                #print 'Info: ',depth,' Need lib',libpath,'for',image
+                dylib_list.append( libpath )
+                findDylibs( libpath, dylib_list, depth+1 )
         
+dylib_list = []
+findDylibs( '../../Source/pysvn/%s' % pysvn_so_string, dylib_list )
+
 print 'Info: Copy files'
 
 cp_list = [
     ('../../Source/pysvn/__init__.py',
         'Contents/pysvn'),
-    ('../../Source/pysvn/_pysvn.so',
+    ('../../Source/pysvn/%s' % pysvn_so_string,
         'Contents/pysvn'),
     ('../../LICENSE.txt',
         'Resources/License.txt'),
@@ -103,13 +120,22 @@ for cp_src, cp_dst_dir_fmt in cp_list:
     os.system( cmd )
 
 print 'Info: Fix the install paths for the dylib files'
+
+fixup_path_list = ['tmp/Contents/pysvn/%s' % pysvn_so_string]
 for libpath in dylib_list:
-    os.system( 'install_name_tool'
-        ' -change'
-        ' %s'
-        ' %s/pysvn/%s'
-        ' %s' %
-            (libpath, install_dir, os.path.basename( libpath ), 'tmp/Contents/pysvn/_pysvn.so') )
+    fixup_path_list.append( 'tmp/Contents/pysvn/' + os.path.basename( libpath ) )
+
+for fixup_path in fixup_path_list:
+    for libpath in dylib_list:
+        if libpath != fixup_path:
+            cmd = ( 'install_name_tool'
+                ' -change'
+                ' %s'
+                ' %s/pysvn/%s'
+                ' %s' %
+                    (libpath, install_dir, os.path.basename( libpath ), fixup_path) )
+            #print 'Debug: cmd %r' % cmd
+            os.system( cmd )
 
 print 'Info: Create tmp/Resources/ReadMe.txt'
 f = file('tmp/Resources/ReadMe.txt','w')
@@ -123,7 +149,7 @@ f.write('''<html>
 
 <h2>Pysvn home <a href="http://pysvn.tigris.org">http://pysvn.tigris.org</a></h2>
 
-<h2>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Barry Scott</h2>
+<h2>&#160;&#160;&#160;&#160;&#160;Barry Scott</h2>
 </body>
 </html>
 ''' % locals() )
