@@ -1,6 +1,6 @@
 //
 // ====================================================================
-// Copyright (c) 2003-2008 Barry A Scott.  All rights reserved.
+// Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 //
 // This software is licensed as described in the file LICENSE.txt,
 // which you should have received as part of this distribution.
@@ -243,6 +243,9 @@ public:
     Py::Object cmd_merge_peg( const Py::Tuple& args, const Py::Dict &kws );
 #if defined( PYSVN_HAS_CLIENT_MERGE_PEG3 )
     Py::Object cmd_merge_peg2( const Py::Tuple& args, const Py::Dict &kws );
+#endif
+#if defined( PYSVN_HAS_CLIENT_MERGE_REINTEGRATE )
+    Py::Object cmd_merge_reintegrate( const Py::Tuple& args, const Py::Dict &kws );
 #endif
     Py::Object cmd_mkdir( const Py::Tuple& args, const Py::Dict &kws );
     Py::Object cmd_move( const Py::Tuple& args, const Py::Dict &kws );
@@ -415,8 +418,8 @@ public:
     long getLong( const char *name, long default_value );
     std::string getUtf8String( const char *name );
     std::string getUtf8String( const char *name, const std::string &default_value );
-    std::string getString( const char *name, const std::string &default_value );
-    std::string getString( const char *name );
+    std::string getBytes( const char *name, const std::string &default_value );
+    std::string getBytes( const char *name );
     svn_opt_revision_t getRevision( const char *name );
     svn_opt_revision_t getRevision( const char *name, svn_opt_revision_kind default_value );
     svn_opt_revision_t getRevision( const char *name, svn_opt_revision_t default_value );
@@ -585,6 +588,38 @@ public:
         }
     }
 
+    virtual Py::Object rich_compare( const Py::Object &other, int op )
+    {
+        if( pysvn_enum_value::check( other ) )
+        {
+            pysvn_enum_value<T> *other_value = static_cast<pysvn_enum_value *>( other.ptr() );
+            switch( op )
+            {
+            case Py_EQ:
+                return Py::Boolean( m_value == other_value->m_value );
+            case Py_NE:
+                return Py::Boolean( m_value != other_value->m_value );
+            case Py_LT:
+                return Py::Boolean( m_value <  other_value->m_value );
+            case Py_LE:
+                return Py::Boolean( m_value <= other_value->m_value );
+            case Py_GT:
+                return Py::Boolean( m_value >  other_value->m_value );
+            case Py_GE:
+                return Py::Boolean( m_value >= other_value->m_value );
+            default:
+            throw Py::RuntimeError( "rich_compare bad op" );
+            }
+        }
+        else
+        {
+            std::string msg( "expecting " );
+            msg += toTypeName( m_value );
+            msg += " object for rich compare ";
+            throw Py::AttributeError( msg );
+        }
+    }
+
     virtual Py::Object repr()
     {
         std::string s("<");
@@ -736,7 +771,7 @@ extern apr_time_t convertStringToTime( const std::string &text, apr_time_t now,
 extern Py::Object propsToObject( apr_hash_t *props, SvnPool &pool );
 extern Py::Object revnumListToObject( apr_array_header_t *revs, SvnPool &pool );
 extern void proplistToObject( Py::List &py_path_propmap_list, apr_array_header_t *props, SvnPool &pool );
-extern Py::String asUtf8String( Py::Object obj );
+extern Py::Bytes asUtf8Bytes( Py::Object obj );
 extern apr_array_header_t *targetsFromStringOrList( Py::Object arg, SvnPool &pool );
 extern Py::List toListOfStrings( Py::Object obj );
 extern apr_array_header_t *arrayOfStringsFromListOfStrings( Py::Object arg, SvnPool &pool );
