@@ -1,6 +1,6 @@
 //
 // ====================================================================
-// Copyright (c) 2003-2008 Barry A Scott.  All rights reserved.
+// Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 //
 // This software is licensed as described in the file LICENSE.txt,
 // which you should have received as part of this distribution.
@@ -304,7 +304,7 @@ Py::Object pysvn_client::cmd_diff_peg( const Py::Tuple &a_args, const Py::Dict &
     const char *relative_to_dir = NULL;
     if( args.hasArg( name_relative_to_dir ) )
     {
-        std_relative_to_dir = args.getString( name_relative_to_dir );
+        std_relative_to_dir = args.getBytes( name_relative_to_dir );
         relative_to_dir = std_relative_to_dir.c_str();
     }
 
